<?php

/**
 * Amibios firmware files API controller.
 *
 * @category   apps
 * @package    amibios
 * @subpackage rest-api
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2018 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/amibios/
 */

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\amibios\Firmware_Files_Library as Firmware_Files_Library;

clearos_load_library('amibios/Firmware_Files_Library');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Amibios firmware files info API controller.
 *
 * @category   apps
 * @package    amibios
 * @subpackage rest-api
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2018 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/amibios/
 */

class Firmware_Files extends ClearOS_REST_Controller
{
    /**
     * Firmware files overview.
     *
     * @param string $id firmware ID
     *
     * @return API response
     */

    function index_get($id = NULL)
    {
        try {
            $amibios = new Firmware_Files_Library();

             if (is_null($id))
                $data = $amibios->get_list();
             else
                $data = $amibios->get($id);

            $this->respond_success($data);
        } catch (\Exception $e) {
            $this->exception_handler($e);
        }
    }

    /**
     * Firmware file delete.
     *
     * @param string $id firmware ID
     *
     * @return API response
     */

    function index_delete($id)
    {
        try {
            $amibios = new Firmware_Files_Library();
            $amibios->delete($id);

            $this->respond_success($data);
        } catch (\Exception $e) {
            $this->exception_handler($e);
        }
    }

    /**
     * Firmware file import.
     *
     * @return API response
     */

    function index_post()
    {
        try {
            $amibios = new Firmware_Files_Library();
            $data = $amibios->import_zip($this->post('zip_file'));

            $this->respond_success();
        } catch (\Exception $e) {
            $this->exception_handler($e);
        }
    }

    /**
     * Firmware file install.
     *
     * @param string $id firmware ID
     *
     * @return API response
     */

    function index_put($id)
    {
        try {
            $amibios = new Firmware_Files_Library();
            $amibios->install($id);

            $this->respond_success();
        } catch (\Exception $e) {
            $this->exception_handler($e);
        }
    }
}
